define_namespace

Macro define_namespace 

macro_rules! define_namespace {
    ($vis:vis $name:ident) => { ... };
}
Define a namespace for static generics. Namespace is like “scope” for generics. Were you to always use DefaultNamespace you would end up with eventually running out of static slots. Defining multiple namespaces allows you to have virtually unlimited set of static generics per each usage.