pub struct DefaultNamespace;Trait Implementations
Sourceimpl Clone for DefaultNamespace
impl Clone for DefaultNamespace
Sourcefn clone(&self) -> DefaultNamespace
fn clone(&self) -> DefaultNamespace
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DefaultNamespace
Sourceimpl Debug for DefaultNamespace
impl Debug for DefaultNamespace
Sourceimpl Namespace for DefaultNamespace
impl Namespace for DefaultNamespace
Sourcefn generic_static<T>() -> &'static Twhere
T: 'static + Zeroable,
fn generic_static<T>() -> &'static Twhere
T: 'static + Zeroable,
The returned reference points to the static namespaced global variable for each
generic
T. The static’s value is zero-initialized. Read moreSourcefn generic_static_const<T, const N: usize>() -> &'static Twhere
T: 'static + Zeroable,
fn generic_static_const<T, const N: usize>() -> &'static Twhere
T: 'static + Zeroable,
The returned reference points to the static namespaced global variable for each
(T, const N: usize) pair (with lifetimes erased). The static’s value is
zero-initialized. Read moreSourceunsafe fn generic_static_mut<T>() -> *mut Twhere
T: 'static + Zeroable,
unsafe fn generic_static_mut<T>() -> *mut Twhere
T: 'static + Zeroable,
Sourceunsafe fn generic_static_const_mut<T, const N: usize>() -> *mut Twhere
T: 'static + Zeroable,
unsafe fn generic_static_const_mut<T, const N: usize>() -> *mut Twhere
T: 'static + Zeroable,
Raw (
*mut T) view of the same slot as
Namespace::generic_static_const: the same T with a different N
is a different address. Read moreAuto Trait Implementations
impl Freeze for DefaultNamespace
impl RefUnwindSafe for DefaultNamespace
impl Send for DefaultNamespace
impl Sync for DefaultNamespace
impl Unpin for DefaultNamespace
impl UnsafeUnpin for DefaultNamespace
impl UnwindSafe for DefaultNamespace